@@ -371,8 +371,23 @@ AudioCD::AudioCD(QWidget *parent, const char *name ) : AudioCD_GUI(parent,name)
 	connect( QRadioButton_DaO, SIGNAL(clicked()), SLOT(slot_toggleTaO()) );
 	connect( QRadioButton_TaO, SIGNAL(clicked()), SLOT(slot_toggleDaO()) );
 
-	//Check for RW-Device
+	//Read config
 	KConfig *config = kapp->config();
+	config->setGroup( "Config - audiocd" );
+
+	QCheckBox_padding->setChecked( config->readBoolEntry("QCheckBox_padding") );
+	QCheckBox_Simulate->setChecked( config->readBoolEntry("QCheckBox_Simulate") );
+	QCheckBox_ignoresize->setChecked( config->readBoolEntry("QCheckBox_ignoresize") );
+	QCheckBox_EjectCD->setChecked( config->readBoolEntry("QCheckBox_EjectCD") );
+	QCheckBox_nofix->setChecked( config->readBoolEntry("QCheckBox_nofix") );
+	QCheckBox_Force->setChecked( config->readBoolEntry("QCheckBox_Force") );
+	QRadioButton_TaO->setChecked( config->readBoolEntry( "QRadioButton_TaO") );
+	QRadioButton_DaO->setChecked( config->readBoolEntry( "QRadioButton_DaO") );
+
+	QComboBox_CDRWBlanking->setCurrentItem( config->readNumEntry("QComboBox_CDRWBlanking") );
+	QComboBox_WriterSpeed->setCurrentItem( config->readNumEntry("QComboBox_WriterSpeed") );
+
+	//Check for RW-Device
 	config->setGroup( "CD-Writer" );
 	if ( config->readEntry( "isRW" ) == "false" ){
 		QComboBox_CDRWBlanking->clear();	
@@ -382,6 +397,8 @@ AudioCD::AudioCD(QWidget *parent, const char *name ) : AudioCD_GUI(parent,name)
 }
 
 AudioCD::~AudioCD(){
+	labelsize = 0;
+	QProgress_CDSize->setProgress( 0 );
 }
 
 //'QRadioButton_TaO' clicked , toggle 'QRadioButton_DaO'
@@ -408,27 +425,61 @@ void AudioCD::slot_toggleTaO(){
 
 //'Add'-Button' clicked
 void AudioCD::slot_addTrack(){
-	//Set sound icon
 	QPixmap sound_icon( ( const char** ) sound_icon_data );
+	int fsize;
+	char buf[256];
 
 	QStringList getName = KFileDialog::getOpenFileNames(0, "*.wav *.WAV", this, 0);
 	for (QStringList::Iterator it = getName.begin();it!=getName.end();++it) {
 		QListBox_Tracklist->insertItem( sound_icon, (const char*) (*it), -1 );
+		QString track = (const char*) (*it);
+		QFileInfo file(track);
+		fsize = file.size();
+		labelsize += fsize;
+		sprintf( buf, "%d MB", labelsize / 1048576 );
+		QTextLabel_CDSize->setText( buf );
+		QProgress_CDSize->setProgress( labelsize );
 	}
 }
 
 //'Delete'-Button' clicked
 void AudioCD::slot_deleteTrack(){
+	int fsize;
+	char buf[256];
+
+	QFileInfo file( QListBox_Tracklist->currentText() );
+	fsize = file.size();
+	labelsize -= fsize;
+	sprintf( buf, "%d MB", labelsize / 1048576 );
+	QTextLabel_CDSize->setText( buf );
+	QProgress_CDSize->setProgress( labelsize );
+
 	QListBox_Tracklist->removeItem( QListBox_Tracklist->currentItem() );
 }
 
 //'Delete all tracks'-Button' clicked
 void AudioCD::slot_deleteAllTracks(){
 	QListBox_Tracklist->clear();
+	QTextLabel_CDSize->setText( "0 MB" );
+	QProgress_CDSize->setProgress( 0 );
+	labelsize = 0;
 }
 
 //'Start-Button' clicked
 void AudioCD::slot_start(){
+
+	//If tracklist empty, return
+	if ( QListBox_Tracklist->count() == 0 ){
+		KMessageBox::error( 0, i18n("Audio CD:\nYou need to add tracks to the tracklist !") );
+		return;
+	}
+
+	//If TaO and DaO RadioButton false, return
+	if ( ! QRadioButton_TaO->isChecked() && ! QRadioButton_DaO->isChecked() ){
+		KMessageBox::error( 0, i18n("Audio CD:\nYou must select 'Track at Once' or 'Disc at Once' !") );
+		return;
+	}
+
 	int rc;
 	KConfig *config = kapp->config();
 
@@ -473,9 +524,10 @@ void AudioCD::slot_start(){
 	   	if( rc == 2 ) (*process) << "speed=4";
 	   	if( rc == 3 ) (*process) << "speed=6";
 	   	if( rc == 4 ) (*process) << "speed=8";
-	   	if( rc == 4 ) (*process) << "speed=10";
-	   	if( rc == 4 ) (*process) << "speed=12";
-	   	if( rc == 4 ) (*process) << "speed=16";
+	   	if( rc == 5 ) (*process) << "speed=10";
+	   	if( rc == 6 ) (*process) << "speed=12";
+	   	if( rc == 7 ) (*process) << "speed=16";
+	   	if( rc == 8 ) (*process) << "speed=20";
 	   	}
 
 	//Add tracks to be written
@@ -644,17 +696,43 @@ void AudioCD::dragEnterEvent(QDragEnterEvent* event){
 }
 
 void AudioCD::dropEvent(QDropEvent *event){
-	QStringList files;
 	QPixmap sound_icon( ( const char** ) sound_icon_data );
+	QStringList files;
+	int fsize;
+	char buf[256];
 
 	if ( QUrlDrag::decodeLocalFiles( event, files ) ) {
 	  for (QStringList::Iterator i=files.begin(); i!=files.end(); ++i){
-			QListBox_Tracklist->insertItem( sound_icon, (const char*) (*i), -1 );
+		QListBox_Tracklist->insertItem( sound_icon, (const char*) (*i), -1 );
+		QString track = (const char*) (*i);
+		QFileInfo file(track);
+		fsize = file.size();
+		labelsize += fsize;
+		sprintf( buf, "%d MB", labelsize / 1048576 );
+		QTextLabel_CDSize->setText( buf );
+		QProgress_CDSize->setProgress( labelsize );
 		}
 	}
 }
 
 //'Quit-Button' clicked
 void AudioCD::slot_exit(){
+
+	//Write config
+	KConfig *config = kapp->config();
+	config->setGroup( "Config - audiocd" );
+
+	config->writeEntry( "QCheckBox_Simulate", QCheckBox_Simulate->isChecked() );
+	config->writeEntry( "QCheckBox_padding", QCheckBox_padding->isChecked() );
+	config->writeEntry( "QCheckBox_ignoresize", QCheckBox_ignoresize->isChecked() );
+	config->writeEntry( "QCheckBox_EjectCD", QCheckBox_EjectCD->isChecked() );
+	config->writeEntry( "QCheckBox_nofix", QCheckBox_nofix->isChecked() );
+	config->writeEntry( "QCheckBox_Force", QCheckBox_Force->isChecked() );
+	config->writeEntry( "QRadioButton_TaO", QRadioButton_TaO->isChecked() );
+	config->writeEntry( "QRadioButton_DaO", QRadioButton_DaO->isChecked() );
+
+	config->writeEntry( "QComboBox_CDRWBlanking", QComboBox_CDRWBlanking->currentItem() );
+	config->writeEntry( "QComboBox_WriterSpeed", QComboBox_WriterSpeed->currentItem() );
+
 	close( true );
 }
