@@ -27,8 +27,46 @@
 #include "imagetype.h"
 
 MasterCD::MasterCD(QWidget *parent, const char *name ) : MasterCD_GUI(parent,name) {
-	//Read Image-Type from config file and display it
+
+	//Read config
 	KConfig *config = kapp->config();
+	config->setGroup( "Config - mastercd" );
+	QCheckBox_BootableCD->setChecked( config->readBoolEntry("QCheckBox_BootableCD") );
+	QCheckBox_Multisession->setChecked( config->readBoolEntry("QCheckBox_Multisession") );
+	QCheckBox_LeaveImage->setChecked( config->readBoolEntry("QCheckBox_LeaveImage") );
+	QCheckBox_ignoresize->setChecked( config->readBoolEntry("QCheckBox_ignoresize") );
+	QCheckBox_Simulate->setChecked( config->readBoolEntry("QCheckBox_Simulate") );
+	QCheckBox_nofix->setChecked( config->readBoolEntry("QCheckBox_nofix") );
+	QCheckBox_EjectCD->setChecked( config->readBoolEntry("QCheckBox_EjectCD") );
+	QCheckBox_Force->setChecked( config->readBoolEntry("QCheckBox_Force") );
+
+	QComboBox_CDRWBlanking->setCurrentItem( config->readNumEntry("QComboBox_CDRWBlanking") );
+	QComboBox_WriterSpeed->setCurrentItem( config->readNumEntry("QComboBox_WriterSpeed") );
+
+	QLineEdit_VolumeID->setText( config->readEntry( "QLineEdit_VolumeID" ) );
+	QLineEdit_Publisher->setText( config->readEntry( "QLineEdit_Publisher" ) );
+	QLineEdit_Preparer->setText( config->readEntry( "QLineEdit_Preparer" ) );
+	QLineEdit_AppID->setText( config->readEntry( "QLineEdit_AppID" ) );
+
+	if ( config->readEntry( "QLineEdit_ImageFile" ) == "" ) {
+		QLineEdit_ImageFile->setText( "/tmp/cd.iso" );
+	}
+	else {
+	QLineEdit_ImageFile->setText( config->readEntry( "QLineEdit_ImageFile" ) );
+	}
+
+	QLineEdit_BootImage->setText( config->readEntry( "" ) );
+
+	if ( strlen( QLineEdit_BootImage->text() ) ) {
+		QPushButton_BootImage->setEnabled( true );
+		QLineEdit_BootImage->setEnabled( true );
+		QCheckBox_BootableCD->setChecked( true );
+	}
+	else {
+		QCheckBox_BootableCD->setChecked( false );
+	}
+
+	//Read Image-Type from config file and display it
 	config->setGroup("Image-Type");
 	QLabel_ImageType->setText( config->readEntry( "Name" ) );
 
@@ -47,11 +85,28 @@ MasterCD::~MasterCD(){
 
 //'SourceDir-Button' clicked
 void MasterCD::slot_setSourceDir(){
-	QLineEdit_SourceDir->setText( KFileDialog::getExistingDirectory() );
+	QString dir = KFileDialog::getExistingDirectory();
+
+	if ( !dir ) return;
+
+	int trackcount = 0;
+	int tc = QListBox_SourceDirs->count();
+	do {
+			if ( dir == QListBox_SourceDirs->text( trackcount ) ){
+				KMessageBox::error( 0, i18n("Master CD:\nThe dir exists already in the tracklist !") );
+				return;
+			}
+		trackcount++;
+	}
+	while ( trackcount < tc );
+
+//	if ( dir ) QListBox_SourceDirs->insertItem( dir );
+	QListBox_SourceDirs->insertItem( dir );
 }
 
-//'File-Manager-Button' clicked
-void MasterCD::slot_fileManager(){
+//Right click on QListBoxItem
+void MasterCD::slot_deleteTrack(){
+	QListBox_SourceDirs->removeItem( QListBox_SourceDirs->currentItem() );
 }
 
 //'ImageFile-Button' clicked
@@ -77,8 +132,28 @@ void MasterCD::slot_imageType(){
 
 //'QCheckBox_BootableCD' clicked , toggle BootableCD-QLineEdit and -Button
 void MasterCD::slot_toggleBootableCD(){
-	QLineEdit_BootImage->setEnabled( QCheckBox_BootableCD->isChecked() ? true:false );
 	QPushButton_BootImage->setEnabled( QCheckBox_BootableCD->isChecked() ? true:false );
+	QLineEdit_BootImage->setEnabled( QCheckBox_BootableCD->isChecked() ? true:false );
+	QLineEdit_BootImage->setText( "" );
+}
+
+//'QCheckBox_Burn on-the-fly' clicked
+void MasterCD::slot_toggle_onthefly(){
+	QPushButton_ImageFile->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	QLineEdit_ImageFile->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	QLineEdit_ImageFile->setText( "" );
+	QCheckBox_LeaveImage->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	QCheckBox_LeaveImage->setChecked( false );
+	QCheckBox_CreateImage->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	QCheckBox_CreateImage->setChecked( QCheckBox_onthefly->isChecked() ? false:true );
+	QCheckBox_Multisession->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	QCheckBox_Multisession->setChecked( false );
+	if ( QCheckBox_BootableCD->isChecked() ) QPushButton_BootImage->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	if ( QCheckBox_BootableCD->isChecked() ) QLineEdit_BootImage->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	QLineEdit_BootImage->setText( "" );
+	QCheckBox_BootableCD->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
+	QCheckBox_BootableCD->setChecked( false );
+	QCheckBox_nofix->setEnabled( QCheckBox_onthefly->isChecked() ? false:true );
 }
 
 //'QCheckBox_WriteCD' clicked
@@ -88,13 +163,14 @@ void MasterCD::slot_toggleWriteCD(){
 	QCheckBox_Simulate->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 	QCheckBox_Force->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 	QCheckBox_ignoresize->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
-	QCheckBox_LeaveImage->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
+	if ( ! QCheckBox_onthefly->isChecked() ) QCheckBox_LeaveImage->setEnabled( QCheckBox_WriteCD->isChecked() ? true:false );
 }
 
 //'QCheckBox_CreateImage' clicked
 void MasterCD::slot_toggleCreateImage(){
 	QCheckBox_BootableCD->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
-	QLineEdit_SourceDir->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
+	QListBox_SourceDirs->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
+	QListBox_SourceDirs->clear();
 	QPushButton_SourceDir->setEnabled( QCheckBox_CreateImage->isChecked() ? true:false );
 }
 
@@ -106,11 +182,27 @@ void MasterCD::slot_multisession(){
 
 //'Start-Button' clicked
 void MasterCD::slot_start(){
+	//Check for QCheckBox_onthefly
+	if ( QCheckBox_onthefly->isChecked() ) {
+		//Check for SourceDirs,
+		if ( QListBox_SourceDirs->count() == 0 ) {
+			KMessageBox::error( 0, i18n("Master CD:\nNot valid Source-Dirs !") );
+			return;
+		}
+		//Check QCheckBox_WriteCD
+		if ( ! QCheckBox_WriteCD->isChecked() ) {
+			KMessageBox::error( 0, i18n("Master CD:\nYou must enable 'WriteCD' !") );
+			return;
+		}
+		slot_PrintSize();
+		return;
+	}
+
 	//--CheckBox_CreateImage is true--
 	if ( QCheckBox_CreateImage->isChecked() ) {
-		//If not valid Source-Dir specified
-		if( ! strlen( QLineEdit_SourceDir->text() ) ) {
-			KMessageBox::error( 0, i18n("Master CD:\nNot valid Source-Dir !") );
+		//If not valid Source-Dirs specified
+		if ( QListBox_SourceDirs->count() == 0 ) {
+			KMessageBox::error( 0, i18n("Master CD:\nNot valid Source-Dirs !") );
 			return;
 		}
 		//If not valid Image-File specified
@@ -158,14 +250,21 @@ void MasterCD::slot_makeImage(){
 
 	//Image-Type
 	config->setGroup("Image-Type");
-	if ( config->readEntry( "Allowlongfilenames" ) == "true" ) (*process) << "-l";
-	if ( config->readEntry( "Rockridgeextensions" ) == "true" ) (*process) << "-R";
-	if ( config->readEntry( "Rockridgewithanonymity" ) == "true" ) (*process) << "-r";
-	if ( config->readEntry( "Jolietextensions" ) == "true" ) (*process) << "-J";
-	if ( config->readEntry( "Omittrailingperiods" ) == "true" ) (*process) << "-d";
-	if ( config->readEntry( "Dontusedeepdirrelocations" ) == "true" ) (*process) << "-D";
-	if ( config->readEntry( "Allowfilesbeginningwithadot" ) == "true" ) (*process) << "-L";
-	if ( config->readEntry( "Omitisoversionnumbers" ) == "true" ) (*process) << "-N";
+	if ( config->readBoolEntry( "Allowlongfilenames" ) ) (*process) << "-l";
+	if ( config->readBoolEntry( "Rockridgeextensions" ) ) (*process) << "-R";
+	if ( config->readBoolEntry( "Rockridgewithanonymity" ) ) (*process) << "-r";
+	if ( config->readBoolEntry( "Jolietextensions" ) ) (*process) << "-J";
+	if ( config->readBoolEntry( "Omittrailingperiods" ) ) (*process) << "-d";
+	if ( config->readBoolEntry( "Dontusedeepdirrelocations" ) ) (*process) << "-D";
+	if ( config->readBoolEntry( "Allowfilesbeginningwithadot" ) ) (*process) << "-L";
+	if ( config->readBoolEntry( "Omitisoversionnumbers" ) ) (*process) << "-N";
+	if ( config->readBoolEntry( "Dontincludebackupfiles" ) ) (*process) << "-no-bak";
+	if ( config->readBoolEntry( "DontuseRR" ) ) (*process) << "-no-rr";
+	if ( config->readBoolEntry( "CreateTRANS_TBLfiles" ) ) (*process) << "-T";
+	if ( config->readBoolEntry( "HideRR_MOVEDdir" ) ) (*process) << "-hide-rr-moved";
+	if ( config->readBoolEntry( "FollowSymbolicLinks" ) ) (*process) << "-f";
+	if ( config->readBoolEntry( "HideTRANS_TBLfiles" ) ) (*process) << "-hide-joliet-trans-tbl";
+	if ( config->readBoolEntry( "Untranslatedfiles" ) ) (*process) << "-U";
 
 	//Arguments for multisession
 	if ( QCheckBox_Multisession->isChecked() && existsSession == true ) {
@@ -190,8 +289,17 @@ void MasterCD::slot_makeImage(){
 	if( QLineEdit_Preparer->text() ) (*process) << "-p" << QLineEdit_Preparer->text();
 	if( QLineEdit_VolumeID->text() ) (*process) << "-V" << QLineEdit_VolumeID->text();
 
-	//Image-File and Source-Dir
-	(*process) << "-o" << QLineEdit_ImageFile->text() << QLineEdit_SourceDir->text();
+	//Image-File
+	(*process) << "-o" << QLineEdit_ImageFile->text();
+
+	//Add the source-dirs to the process
+	int trackcount = 0;
+	int tc = QListBox_SourceDirs->count();
+	do {
+		(*process) << QListBox_SourceDirs->text( trackcount );
+		trackcount++;
+	}
+	while ( trackcount < tc );
 
 	//Connect the Abort-Button from ImgProOut-Dialog to Abort-Handler
 	connect( imgprocoutdlg.Button, SIGNAL(clicked()), this, SLOT(abort_handler()));
@@ -256,9 +364,10 @@ void MasterCD::slot_writeCD(){
 	   	if( rc == 2 ) (*process) << "speed=4";
 	   	if( rc == 3 ) (*process) << "speed=6";
 	   	if( rc == 4 ) (*process) << "speed=8";
-	   	if( rc == 4 ) (*process) << "speed=10";
-	   	if( rc == 4 ) (*process) << "speed=12";
-	   	if( rc == 4 ) (*process) << "speed=16";
+	   	if( rc == 5 ) (*process) << "speed=10";
+	   	if( rc == 6 ) (*process) << "speed=12";
+	   	if( rc == 7 ) (*process) << "speed=16";
+	   	if( rc == 8 ) (*process) << "speed=20";
 	   	}
 
 	//Set the Image
@@ -287,9 +396,9 @@ void MasterCD::slot_writeCD(){
 
 //'Calculate-Button' clicked
 void MasterCD::slot_calculateSize() {
-	//If not valid Source-Dir specified
-	if( ! strlen( QLineEdit_SourceDir->text() ) ) {
-		KMessageBox::error( 0, i18n("Calculate size:\nNot valid Source-Dir !") );
+	//If not valid Source-Dirs specified
+	if( QListBox_SourceDirs->count() == 0 ) {
+		KMessageBox::error( 0, i18n("Calculate size:\nNot valid Source-Dirs !") );
 		return;
 	}
 
@@ -303,10 +412,14 @@ void MasterCD::slot_calculateSize() {
 	process->clearArguments();
  	(*process) << "mkisofs" << "-print-size" << "-f";
 
-	//Source-Dir
-	QString sdir = QLineEdit_SourceDir->text();
-	if( sdir == "User defined ISO-Tree !" ) (*process) << "/tmp/isoimage/";
-	else (*process) << QLineEdit_SourceDir->text();
+	//Add the source-dirs to the process
+	int trackcount = 0;
+	int tc = QListBox_SourceDirs->count();
+	do {
+		(*process) << QListBox_SourceDirs->text( trackcount );
+		trackcount++;
+	}
+	while ( trackcount < tc );
 
 	//Connect the 'processExited' Signal to the 'slotProcessFinished' Slot
 	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT(slot_calculateProcessExited(KProcess *)));
@@ -341,6 +454,167 @@ void MasterCD::slot_calculateProcessExited(KProcess *rcproc) {
 	}
 }
 
+//---Write CD on-the-fly---
+void MasterCD::slot_writeCD_onthefly(){
+	char tmp[50];
+
+	//KShellProcess
+	KShellProcess *shellProcess = new KShellProcess();
+
+	//Set args for mkisofs
+ 	(*shellProcess) << "mkisofs" << "-f";
+
+	//Image-Type
+	KConfig *config = kapp->config();
+	config->setGroup("Image-Type");
+	if ( config->readBoolEntry( "Allowlongfilenames" ) ) (*shellProcess) << "-l";
+	if ( config->readBoolEntry( "Rockridgeextensions" ) ) (*shellProcess) << "-R";
+	if ( config->readBoolEntry( "Rockridgewithanonymity" ) ) (*shellProcess) << "-r";
+	if ( config->readBoolEntry( "Jolietextensions" ) ) (*shellProcess) << "-J";
+	if ( config->readBoolEntry( "Omittrailingperiods" ) ) (*shellProcess) << "-d";
+	if ( config->readBoolEntry( "Dontusedeepdirrelocations" ) ) (*shellProcess) << "-D";
+	if ( config->readBoolEntry( "Allowfilesbeginningwithadot" ) ) (*shellProcess) << "-L";
+	if ( config->readBoolEntry( "Omitisoversionnumbers" ) ) (*shellProcess) << "-N";
+	if ( config->readBoolEntry( "Dontincludebackupfiles" ) ) (*shellProcess) << "-no-bak";
+	if ( config->readBoolEntry( "DontuseRR" ) ) (*shellProcess) << "-no-rr";
+	if ( config->readBoolEntry( "CreateTRANS_TBLfiles" ) ) (*shellProcess) << "-T";
+	if ( config->readBoolEntry( "HideRR_MOVEDdir" ) ) (*shellProcess) << "-hide-rr-moved";
+	if ( config->readBoolEntry( "FollowSymbolicLinks" ) ) (*shellProcess) << "-f";
+	if ( config->readBoolEntry( "HideTRANS_TBLfiles" ) ) (*shellProcess) << "-hide-joliet-trans-tbl";
+	if ( config->readBoolEntry( "Untranslatedfiles" ) ) (*shellProcess) << "-U";
+
+	//Arguments for multisession
+	if ( QCheckBox_Multisession->isChecked() && existsSession == true ) {
+		char tmp[50], dev[10], outdev[10];
+		char *tmpdev;
+		sprintf( tmp, "%d,%d", MS_Start, MS_End );
+	 	(*shellProcess) << "-C" << tmp;
+		config->setGroup("CD-Writer");
+		strcpy(dev, config->readEntry("Device"));
+		printf("%s\n", strtok(dev, "="));
+		while ( (tmpdev=strtok(NULL, "=")) != NULL)
+		strcpy(outdev, tmpdev);
+		(*shellProcess) << "-M" << outdev;
+	}
+
+	//Add CD-Identification
+	if( QLineEdit_VolumeID->text() ){
+		QString volumeid;
+		volumeid.append( "-V '" );
+		volumeid.append( QLineEdit_VolumeID->text() );
+		volumeid.append( "'" );
+		(*shellProcess) << volumeid;
+	}
+
+	if( QLineEdit_Publisher->text() ){
+		QString publisher;
+		publisher.append( "-P '" );
+		publisher.append( QLineEdit_Publisher->text() );
+		publisher.append( "'" );
+		(*shellProcess) << publisher;
+	}
+
+	if( QLineEdit_Preparer->text() ){
+		QString preparer;
+		preparer.append( "-p '" );
+		preparer.append( QLineEdit_Preparer->text() );
+		preparer.append( "'" );
+		(*shellProcess) << preparer;
+	}
+
+	if( QLineEdit_AppID->text() ){
+		QString appid;
+		appid.append( "-A '" );
+		appid.append( QLineEdit_AppID->text() );
+		appid.append( "'" );
+		(*shellProcess) << appid;
+	}
+
+	//Add the source-dirs to the process
+	int trackcount = 0;
+	int tc = QListBox_SourceDirs->count();
+	do {
+		(*shellProcess) << QListBox_SourceDirs->text( trackcount );
+		trackcount++;
+	}
+	while ( trackcount < tc );
+
+	//For KShellProcess
+	(*shellProcess) << "|";
+
+	//Set args for cdrecord
+	(*shellProcess) << "cdrecord" << "-v";
+
+	//Set the CD-Writer first
+	config->setGroup("CD-Writer");
+	(*shellProcess) << config->readEntry("Device");
+
+	//Set Burn-Proof
+	if( config->readNumEntry("BurnProof") == true ) (*shellProcess) << "driveropts=burnproof";
+
+	//Set CD-Writer Options to KProcess
+	if( QCheckBox_EjectCD->isChecked() ) (*shellProcess) << "-eject";
+	if( QCheckBox_Force->isChecked() ) (*shellProcess) << "-force";
+	if( QCheckBox_Multisession->isChecked() ) (*shellProcess) << "-multi";
+	if( QCheckBox_Simulate->isChecked() ) (*shellProcess) << "-dummy";
+	if( QCheckBox_nofix->isChecked() ) (*shellProcess) << "-nofix";
+	if( QCheckBox_ignoresize->isChecked() ) (*shellProcess) << "-ignsize";
+
+	//Set CD-RW Options to 	int Kprocess
+	int rc;
+	if( (rc = QComboBox_CDRWBlanking -> currentItem()) )
+		{
+	   	if( rc == 1 ) (*shellProcess) << "blank=all";
+	   	if( rc == 2 ) (*shellProcess) << "blank=fast";
+	   	if( rc == 3 ) (*shellProcess) << "blank=track";
+	   	if( rc == 4 ) (*shellProcess) << "blank=unreserve";
+	   	if( rc == 5 ) (*shellProcess) << "blank=trtrail";
+	   	if( rc == 6 ) (*shellProcess) << "blank=unclose";
+	   	if( rc == 7 ) (*shellProcess) << "blank=session";
+	   	}
+
+	//Set CD-Writer Speed to Kprocess
+	if( (rc = QComboBox_WriterSpeed -> currentItem()) )
+		{
+	   	if( rc == 0 ) (*shellProcess) << "speed=1";
+	   	if( rc == 1 ) (*shellProcess) << "speed=2";
+	   	if( rc == 2 ) (*shellProcess) << "speed=4";
+	   	if( rc == 3 ) (*shellProcess) << "speed=6";
+	   	if( rc == 4 ) (*shellProcess) << "speed=8";
+	   	if( rc == 5 ) (*shellProcess) << "speed=10";
+	   	if( rc == 6 ) (*shellProcess) << "speed=12";
+	   	if( rc == 7 ) (*shellProcess) << "speed=16";
+	   	if( rc == 8 ) (*shellProcess) << "speed=20";
+	   	}
+
+	//Set filesystem size
+	sprintf( tmp, "tsize=%d", FS_Size );
+	(*shellProcess) << tmp;
+
+	//Last arg
+	(*shellProcess) << "-";
+
+	//Connect the Abort-Button from ImgProOut-Dialog to Abort-Handler
+	connect( procoutdlg.QPushButton_OK, SIGNAL(clicked()), this, SLOT(abort_handler()));
+
+	//Connect the 'processExited' Signal to the 'slotProcessFinished' Slot
+	connect( shellProcess, SIGNAL(processExited(KProcess *)), this, SLOT(slot_burnProcessExited(KProcess *)));
+
+	//Connect with slotRecStderr to update KProgress (Write- / Buffer-Status) and StatusLine
+	connect( shellProcess, SIGNAL(receivedStdout (KProcess *, char *, int) ), this, SLOT(slot_burnRecStderr (KProcess *, char *, int) ));
+	connect( shellProcess, SIGNAL(receivedStderr (KProcess *, char *, int) ), this, SLOT(slot_burnRecStderr (KProcess *, char *, int) ));
+
+	//Start KProcess
+	if( ! shellProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput ) )
+		{
+		KMessageBox::error( 0, i18n("Write CD:\nCould not start cdrecord !") );
+		return;
+		}
+
+	procoutdlg.StatusLabel -> setText( i18n("Prepare for write...") );
+	procoutdlg.QPushButton_OK->setEnabled( false );
+}
+
 //KProcess outout analysis
 void MasterCD::slot_calculateRecStderr( KProcess *, char *buffer, int buflen) {
 	char *c, buf[1024];
@@ -479,7 +753,7 @@ void MasterCD::slot_burnProcessExited(KProcess *rcproc) {
 				return;
 			}
 		//If 'Leave Image' CheckBox false, delete the Imagefile
-		if ( rcproc->exitStatus() == 0 && ! QCheckBox_LeaveImage->isChecked() ) QFile::remove( QLineEdit_ImageFile->text() );
+		if ( rcproc->exitStatus() == 0 && ! QCheckBox_LeaveImage->isChecked() && ! QCheckBox_onthefly->isChecked() ) QFile::remove( QLineEdit_ImageFile->text() );
 		procoutdlg.QPushButton_OK->setText( "&OK" );
 		procoutdlg.QPushButton_OK->setEnabled( true );
 	}
@@ -628,6 +902,85 @@ void MasterCD::slot_MSInfoExited(KProcess *rcproc) {
 	}
 }
 
+//KProcess for printsize
+void MasterCD::slot_PrintSize() {
+	//KProcess arguments
+	KProcess *process = new KProcess();
+	process->clearArguments();
+ 	(*process) << "mkisofs" << "-quiet" << "-print-size";
+
+	//Add the source-dirs to the process
+	int trackcount = 0;
+	int tc = QListBox_SourceDirs->count();
+	do {
+		(*process) << QListBox_SourceDirs->text( trackcount );
+		trackcount++;
+	}
+	while ( trackcount < tc );
+
+	//Connect the Abort-Button from ImgProOut-Dialog to Abort-Handler
+	connect( imgprocoutdlg.Button, SIGNAL(clicked()), this, SLOT(abort_handler()));
+
+	//Connect the 'processExited' Signal
+	connect( process, SIGNAL(processExited(KProcess *)), this, SLOT( slot_PrintSizeExited( KProcess * ) ));
+
+	//Connect with slotRecStderr to update KProgress
+	connect( process, SIGNAL(receivedStdout(KProcess *, char *, int) ), this, SLOT( slot_PrintSizeOutput(KProcess *, char *, int ) ));
+	connect( process, SIGNAL(receivedStderr(KProcess *, char *, int) ), this, SLOT( slot_PrintSizeOutput(KProcess *, char *, int ) ));
+
+	//Start KProcess
+	if( ! process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) KMessageBox::error( 0, i18n("PrintSize:\nCould not start cdrecord !") );
+
+	procoutdlg.StatusLabel -> setText( i18n("Retrieve filesystem size...") );
+	procoutdlg.show();
+}
+
+//KProcess Analyse for print-size
+void MasterCD::slot_PrintSizeOutput( KProcess *, char *s, int n ){
+	char *c, buf[1024];
+
+	if( !n ) return;
+	
+	bzero( buf, sizeof( buf ) );
+	strncpy( buf, s, n > (int) sizeof( buf ) ? sizeof(buf) - 1 : n );
+
+	if( strstr( buf, "written =" ) ) {
+		if( (c = rindex( buf, ' ' ) ) ) {		
+			FS_Size = atoi( c ) * 2048;
+		}
+	}
+}
+
+//KProcess 'print-size' finished
+void MasterCD::slot_PrintSizeExited(KProcess *rcproc) {
+	//Check, if KProcess exited normally...
+	if( rcproc->normalExit() ) {
+ 			if( rcproc->exitStatus() != 0 ) {
+				switch ( rcproc->exitStatus() )
+				{
+					case 13:		procoutdlg.StatusLabel -> setText( i18n( "Error: You don't have enough permissions !" ) );
+										break;
+
+					case 19:		procoutdlg.StatusLabel -> setText( i18n( "Error: Can't open SCSI-Driver !" ) );
+										break;
+
+					case 254:	procoutdlg.StatusLabel -> setText( i18n( "Error: Corrupt CD in the Writer-Device !" ) );
+										break;
+
+					case 255:	procoutdlg.StatusLabel -> setText( i18n( "Error: No CD in the Writer-Device !" ) );
+										break;
+				}
+				QString statusout;
+				statusout.sprintf( "Exit status: %d", rcproc->exitStatus() );
+				KMessageBox::error( 0, i18n("Printsize:\nAn error is occurred !\n" + statusout) );
+				procoutdlg.QPushButton_OK->setText( "&OK" );
+				return;
+			}
+	//Write CD on-the-fly
+	slot_writeCD_onthefly();
+	}
+}
+
 //Abort-Handler
 void MasterCD::abort_handler(){
 	//Close dialogs
@@ -637,5 +990,30 @@ void MasterCD::abort_handler(){
 
 //'Quit-Button' clicked
 void MasterCD::slot_quit(){
+
+	//Write config
+	KConfig *config = kapp->config();
+	config->setGroup( "Config - mastercd" );
+
+	config->writeEntry( "QCheckBox_BootableCD", QCheckBox_BootableCD->isChecked() );
+	config->writeEntry( "QCheckBox_Multisession", QCheckBox_Multisession->isChecked() );
+	config->writeEntry( "QCheckBox_LeaveImage", QCheckBox_LeaveImage->isChecked() );
+	config->writeEntry( "QCheckBox_ignoresize", QCheckBox_ignoresize->isChecked() );
+	config->writeEntry( "QCheckBox_Simulate", QCheckBox_Simulate->isChecked() );
+	config->writeEntry( "QCheckBox_nofix", QCheckBox_nofix->isChecked() );
+	config->writeEntry( "QCheckBox_EjectCD", QCheckBox_EjectCD->isChecked() );
+	config->writeEntry( "QCheckBox_Force", QCheckBox_Force->isChecked() );
+
+	config->writeEntry( "QComboBox_CDRWBlanking", QComboBox_CDRWBlanking->currentItem() );
+	config->writeEntry( "QComboBox_WriterSpeed", QComboBox_WriterSpeed->currentItem() );
+
+	config->writeEntry( "QLineEdit_VolumeID", QLineEdit_VolumeID->text() );
+	config->writeEntry( "QLineEdit_Publisher", QLineEdit_Publisher->text() );
+	config->writeEntry( "QLineEdit_Preparer", QLineEdit_Preparer->text() );
+	config->writeEntry( "QLineEdit_AppID", QLineEdit_AppID->text() );
+
+	config->writeEntry( "QLineEdit_ImageFile", QLineEdit_ImageFile->text() );
+	config->writeEntry( "QLineEdit_BootImage", QLineEdit_BootImage->text() );
+
 	close(true);
 }
