@@ -33,7 +33,7 @@ protected:
 	ImgProcOut imgprocoutdlg;
 
 private:
-	int MS_Start, MS_End;
+	int MS_Start, MS_End, FS_Size;
 	bool existsSession;
 
 protected slots:
@@ -41,16 +41,18 @@ protected slots:
 	void slot_start();
 	void abort_handler();
 	void slot_setSourceDir();
-	void slot_fileManager();
 	void slot_setImageFile();
 	void slot_setBootImage();
 	void slot_imageType();
 	void slot_toggleBootableCD();
 	void slot_toggleWriteCD();
 	void slot_toggleCreateImage();
+	void slot_toggle_onthefly();
 	void slot_multisession();
 	void slot_makeImage();
 	void slot_writeCD();
+	void slot_writeCD_onthefly();
+	void slot_deleteTrack();
 	void slot_calculateSize();
 	void slot_calculateProcessExited(KProcess *);
 	void slot_calculateRecStderr(KProcess *, char *, int);
@@ -61,6 +63,10 @@ protected slots:
 	void slot_MSInfo();
 	void slot_MSOutput( KProcess *, char *, int);
 	void slot_MSInfoExited(KProcess *);
+	void slot_PrintSize();
+	void slot_PrintSizeOutput( KProcess *, char *, int);
+	void slot_PrintSizeExited(KProcess *);
+
 };
 
 #endif
